pub struct SerializableRoleGraph {
pub role: RoleName,
pub nodes: AHashMap<u64, Node>,
pub edges: AHashMap<u64, Edge>,
pub documents: AHashMap<String, IndexedDocument>,
pub thesaurus: Thesaurus,
pub aho_corasick_values: Vec<u64>,
pub ac_reverse_nterm: AHashMap<u64, NormalizedTermValue>,
}Expand description
A serializable representation of RoleGraph for JSON serialization/deserialization.
This struct excludes the Aho-Corasick automata which cannot be directly serialized, but includes all the necessary data to reconstruct it.
Fields
role: RoleNameThe role of the graph
nodes: AHashMap<u64, Node>A mapping from node IDs to nodes
edges: AHashMap<u64, Edge>A mapping from edge IDs to edges
documents: AHashMap<String, IndexedDocument>A mapping from document IDs to indexed documents
thesaurus: ThesaurusA thesaurus is a mapping from synonyms to concepts
aho_corasick_values: Vec<u64>Aho-Corasick values (needed to rebuild the automata)
ac_reverse_nterm: AHashMap<u64, NormalizedTermValue>reverse lookup - matched id into normalized term
Implementations